from confluence.models.icon import Icon
import logging

logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


def test_create_with_valid_json():
    i = Icon({
        'path': 'https://a.com',
        'width': 200,
        'height': 201,
        'isDefault': False
    })

    assert str(i) == 'https://a.com [200x201]'



from confluence.models.label import Label
import logging

logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


def test_create_label():
    label = Label({
        "prefix": "global",
        "name": "branding",
        "id": "12345"
    })

    assert str(label) == 'branding'



from confluence.models.content import Content
import logging

logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


def test_create_group_with_valid_json():
    a = Content({
        "id": "att35459744",
        "type": "attachment",
        "status": "current",
        "title": "Puppet Architecture.png",
        "metadata": {
            "comment": "Added by UWC, the Universal Wiki Converter",
            "mediaType": "image/png",
            "labels": {
                "results": [],
                "start": 0,
                "limit": 200,
                "size": 0,
            }
        },
        "extensions": {
            "mediaType": "image/png",
            "fileSize": 61601,
            "comment": "Added by UWC, the Universal Wiki Converter"
        }
    })
    assert str(a) == 'att35459744 - Puppet Architecture.png'



from confluence.models.content import Content
import logging

logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


def test_create_with_minimal_json():
    p = Content({
        'id': 1,
        'title': 'Hello',
        'status': 'current',
        'type': 'page'
    })

    assert str(p) == '1 - Hello'


def test_create_complete():
    p = Content({
        "id": "65577",
        "type": "page",
        "status": "current",
        "title": "SandBox",
        "space": {
            "id": 98306,
            "key": "SAN",
            "name": "SandBox",
            "type": "global"
        },
        "history": {
            "latest": True,
            "createdBy": {
                "type": "anonymous",
                "profilePicture": {
                    "path": "anonymous.png",
                    "width": 48,
                    "height": 48,
                    "isDefault": True
                },
                "displayName": "Anonymous"
            },
            "createdDate": "2017-09-22T11:03:07.420+01:00"
        },
        "version": {
            "by": {
                "type": "known",
                "username": "user",
                "userKey": "12345",
                "profilePicture": {
                    "path": "default.png",
                    "width": 48,
                    "height": 48,
                    "isDefault": True
                },
                "displayName": "user"
            },
            "when": "2017-10-28T17:05:56.026+01:00",
            "message": "",
            "number": 8,
            "minorEdit": False,
            "hidden": False
        },
        "body": {
            "storage": {
                "value": "",
                "representation": "storage",
                "_expandable": {
                    "content": "/rest/api/content/65577"
                }
            }
        },
        "metadata": {
        },
        "extensions": {
            "position": "none"
        }
    })

    assert p.body.storage == ''
    assert p.body.storage_representation == 'storage'
    assert not hasattr(p.body, 'edit')

    assert p.history.latest

    assert p.space.id == 98306



from confluence.models.space import Space, SpaceProperty
import logging

logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


def test_create_minimal_space():
    s = Space({
        'id': 1,
        'key': 'TEST',
        'name': 'Test',
        'type': 'personal'
    })

    assert str(s) == '1 - TEST | Test'


def test_create_space_all():
    s = Space({
        'id': 1,
        'key': 'TEST',
        'name': 'Test',
        'type': 'personal',
        'description': '',
        'homepage': {
            'id': 1,
            'title': 'Hello',
            'status': 'current',
            'type': 'page',
            'space': {
                'id': 1,
                'key': 'TEST',
                'name': 'Test',
                'type': 'personal'
            }
        },
        'icon': {
            'path': 'https://a.com',
            'width': 200,
            'height': 201,
            'isDefault': False
        },
        'metadata': {

        }
    })

    assert str(s) == '1 - TEST | Test'
    assert s.icon is not None
    assert s.homepage is not None


def test_create_space_property_minimal():
    s = SpaceProperty({
        'space': {
            'id': 1,
            'key': 'TST',
            'name': 'Example space',
            'type': 'personal',
            'description': {
                'plain': {
                    'value': 'This is an example space',
                    'representation': 'plain'
                }
            },
            'metadata': {},
            '_links': {
                'self': 'http://myhost:8080/confluence/rest/api/space/TST'
            }
        },
        'key': 'example-property-key',
        'value': {
            'anything': 'goes'
        },
        'version': {
            'number': 2,
            'minorEdit': False,
            'hidden': False
        }
    })

    assert str(s) == 'example-property-key'
    assert s.version.number == 2
    assert s.space.key == 'TST'



import logging
from typing import Any, Dict

logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


class ContentBody:
    """
    Represents the body of a content(blog|page|comment|attachment) in confluence.

    This has several different representations which may be present or not.
    """

    def __init__(self, json):  # type: (Dict[str, Any]) -> None
        if 'storage' in json:
            self.storage = json['storage']['value']  # type: str
            self.storage_representation = json['storage']['representation']  # type: str
        if 'editor' in json:
            self.editor = json['storage']['value']  # type: str
            self.editor_representation = json['storage']['representation']  # type: str
        if 'view' in json:
            self.view = json['storage']['value']  # type: str
            self.view_representation = json['storage']['representation']  # type: str
        if 'export_view' in json:
            self.export_view = json['storage']['value']  # type: str
            self.export_view_representation = json['storage']['representation']  # type: str
        if 'styled_view' in json:
            self.styled_view = json['storage']['value']  # type: str
            self.styled_view_representation = json['storage']['representation']  # type: str
        if 'anonymous_export_view' in json:
            self.anonymous_export_view = json['storage']['value']  # type: str
            self.anonymous_export_view_representation = json['storage']['representation']  # type: str



from confluence.models.group import Group
import logging

logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


def test_create_group_with_valid_json():
    g = Group({
        'type': 'Type',
        'name': 'Name'
    })
    assert str(g) == 'Name'



from confluence.models.content import Content
import logging

logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


def test_create_group_with_valid_json():
    c = Content({
        "id": "39128239",
        "type": "comment",
        "status": "current",
        "title": "Re: Puppet: Architecture Overview",
        "extensions": {
            "location": "inline",
            "_expandable": {
                "inlineProperties": "",
                "resolution": ""
            }
        }
    })
    assert str(c) == '39128239 - Re: Puppet: Architecture Overview'



from codecs import open
from os import path
from setuptools import setup, find_packages

readme = path.join(path.abspath(path.dirname(__file__)), 'README.rst')

with open(readme, encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='confluence-rest-library',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    version='0.11.0',
    description='A simple wrapper around the Confluence REST API.',
    long_description=long_description,
    author='David Tyler',
    author_email='davet.code@gmail.com',
    url='https://github.com/DaveTCode/confluence-python-lib',
    keywords=['confluence'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ],
    python_requires='>=2.7,!=3.0,!=3.1,!=3.2,!=3.3,!=3.4',
    setup_requires=['pytest-runner', 'pypandoc', 'typing'],
    install_requires=['requests >= 2.18.4, < 3.0.0a0'],
    tests_require=['pytest >= 3.0.7, < 4.0.0a0', 'pytest-cov >= 2.5.0, < 3.0.0a0']
)
